Package 'harlem'

Title: Color Palettes Inspired by Harlem Renaissance Artists
Description: The 'harlem' package offers a collection of color palettes inspired by iconic works from Harlem Renaissance artists. These palettes can be easily integrated into data visualizations in R.
Authors: Shaurita Hutchins [aut, cre] (ORCID: <https://orcid.org/0000-0002-7687-0059>, Computational biologist and package author)
Maintainer: Shaurita Hutchins <[email protected]>
License: MIT + file LICENSE
Version: 0.0.1
Built: 2026-06-10 02:49:22 UTC
Source: https://github.com/sdhutchins/harlem

Help Index


harlem

Description

A collection of color palettes inspired by iconic works from Harlem Renaissance artists.

Details

A collection of color palettes inspired by Harlem Renaissance artists and their pieces of art.

Author(s)

Maintainer: Shaurita Hutchins [email protected]

See Also

Useful links:


Harlem Renaissance Palette Generator

Description

Generates color palettes inspired by artworks from the Harlem Renaissance era.

Usage

harlem_palette(
  name = "LawrenceStreetScene",
  n = NULL,
  type = c("discrete", "continuous")
)

Arguments

name

Character string. Name of the desired palette. Available choices are included in the package documentation.

n

Integer. Number of colors desired. If omitted, uses all available colors from the chosen palette.

type

Character string. Either "continuous" or "discrete". Use "continuous" to interpolate between colors.

Value

A vector of colors.

Examples

harlem_palette("LawrenceStreetScene")
harlem_palette("BeardenConjurWoman", 5)
harlem_palette("MotleyBlues", type = "continuous")

A list of Harlem Renaissance-inspired palettes

Description

A list of Harlem Renaissance-inspired palettes

Usage

harlem_palettes

Format

An object of class list of length 16.