| Title: | Color Palettes Inspired by Harlem Renaissance Artists |
|---|---|
| Description: | The 'harlem' package offers a collection of color palettes inspired by iconic works from Harlem Renaissance artists. These palettes can be easily integrated into data visualizations in R. |
| Authors: | Shaurita Hutchins [aut, cre] (ORCID: <https://orcid.org/0000-0002-7687-0059>, Computational biologist and package author) |
| Maintainer: | Shaurita Hutchins <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.1 |
| Built: | 2026-06-10 02:49:22 UTC |
| Source: | https://github.com/sdhutchins/harlem |
A collection of color palettes inspired by iconic works from Harlem Renaissance artists.
A collection of color palettes inspired by Harlem Renaissance artists and their pieces of art.
Maintainer: Shaurita Hutchins [email protected]
Useful links:
Generates color palettes inspired by artworks from the Harlem Renaissance era.
harlem_palette( name = "LawrenceStreetScene", n = NULL, type = c("discrete", "continuous") )harlem_palette( name = "LawrenceStreetScene", n = NULL, type = c("discrete", "continuous") )
name |
Character string. Name of the desired palette. Available choices are included in the package documentation. |
n |
Integer. Number of colors desired. If omitted, uses all available colors from the chosen palette. |
type |
Character string. Either "continuous" or "discrete". Use "continuous" to interpolate between colors. |
A vector of colors.
harlem_palette("LawrenceStreetScene") harlem_palette("BeardenConjurWoman", 5) harlem_palette("MotleyBlues", type = "continuous")harlem_palette("LawrenceStreetScene") harlem_palette("BeardenConjurWoman", 5) harlem_palette("MotleyBlues", type = "continuous")
A list of Harlem Renaissance-inspired palettes
harlem_palettesharlem_palettes
An object of class list of length 16.
This function displays the color palette visually as an image plot. The palette name, if it exists, will be displayed as a label on the plot.
print_palette(x, ...)print_palette(x, ...)
x |
A color palette represented as a vector of color hex codes. |
... |
Additional arguments to be passed to the underlying |
A plot displaying the color palette.
my_palette <- c("#D7AA50", "#C13E20", "#3E5D33", "#E6E6E6") attr(my_palette, "name") <- "Example Palette" print_palette(my_palette)my_palette <- c("#D7AA50", "#C13E20", "#3E5D33", "#E6E6E6") attr(my_palette, "name") <- "Example Palette" print_palette(my_palette)